Changelog
==============

V2.3.1(2022-05-12)

    - bug fixed about removing connection failed.

V2.3.0(2022-05-12)

    - UI of Redis Scan improved.
    - Delete key by clicking "Delete Key" button in headerbar.
    - Delete selected row in Redis imporved.
    - bug fixed.

V2.2.0(2022-05-01)

    - Update value by double clicking the value cell.
    - Add key by clicking "New Key" button in headerbar
      (String,List,Hash,Set,Zset,Stream are supported).
    - Execute Redis commands in Console.

V2.1.4 & V2.1.5(2022-04-23)

    - delete data in Redis by clicking delete button in headerbar.
    - delete data in Memcached by clicking delete button in headerbar.
    - Redis Set,ZSet supported.
    - UI bug fixed in Ubuntu 22.04LTS.

V2.1.2 & V2.1.3(2022-04-15)

    - Fixed an bug(missing ui icon in some of the Linux distributions).

V2.1.1(2022-04-14)

    - UI improved.
    - Fixed an installation bug by using source package.

V2.1.0(2022-04-11)

    - Redis Stream supported.

V2.0.1(2022-04-09)

    - Fixed bug of wrong path of icon in About Dialog.

V2.0.0(2022-03-29)

    - Added support for Connecting to Redis, including standalone and cluster.
    - Redis String, Redis Hash, Redis List supported.
    - The project is renamed to KvFront.

V1.1.0(2022-03-08)

    - Made it run well on Ubuntu 20.04LTS.

V1.0.2.1(2017-09-10)

    - UI optimised under Adwaita theme.

V1.0.2.0(2017-09-02)

    - Added functionality to flush the memcached.

V1.0.1.0(2017-07-04)

    - added functionality to show the detail value of a key.
    - showed the json string value with formatted json string.
  
V1.0.0.0(2017-06-29)

    - Added support for memcached.
